﻿<cfcomponent displayname="demo" hint="Demonstration CFC" output="false">

	<cffunction name="init" access="public" returntype="any">
		<cfreturn THIS />
	</cffunction>

	<cffunction name="getAllMessages" displayname="getAllMessages" description="Getting all messages" hint="Getting all messages" access="remote" output="false" returntype="array">
		<cfargument name="nick" displayName="nick" type="string" hint="Nickname" required="true" />
		
		<cfset var result = arrayNew(1) />
		<cfset var qryAllMessages = "" />

		<cfstoredproc procedure="getAllMessages" datasource="demo">
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.nick#" />
			<cfprocresult name="qryAllMessages" resultset="1" />
		</cfstoredproc>

		<cfset result = QueryToArrayOfStructures(qryAllMessages) />

		<cfreturn result />
	</cffunction>

	<cffunction name="getMessages" displayname="getMessages" description="Getting new messages from last visit" hint="Getting new messages from last visit" access="remote" output="false" returntype="array">
		<cfargument name="nick" displayName="nick" type="string" hint="Nickname" required="true" />
		
		<cfset var result = arrayNew(1) />
		<cfset var qryMessages = "" />

		<cfstoredproc procedure="getMessages" datasource="demo">
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.nick#" />
			<cfprocresult name="qryMessages" resultset="1" />
		</cfstoredproc>

		<cfset result = QueryToArrayOfStructures(qryMessages) />

		<cfreturn result />
	</cffunction>
	
	<cffunction name="sendGroupMessage" displayname="sendGroupMessage" description="Sending message to a group" hint="Sending message to a group" access="remote" output="false" returntype="void">
		<cfargument name="nick" displayName="nick" type="string" hint="Nickname to identify user" required="true" />
		<cfargument name="group" displayName="group" type="string" hint="Group name" required="true" />
		<cfargument name="msg" displayName="msg" type="string" hint="Message to send" required="true" />

		<cfset var event = structNew() />
		
		<cfstoredproc procedure="sendGroupMessage" datasource="demo">
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.nick#" />
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.group#" />
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.msg#" />
		</cfstoredproc>

		<cfset event.body = arguments.group />
		<cfset event.destination = "ColdFusionGateway" />
		<cfset ret = SendGatewayMessage("demo", event) />

	</cffunction>

	<cffunction name="sendDirectMessage" displayname="sendDirectMessage" description="Sending direct message" hint="Sending direct message" access="remote" output="false" returntype="string">
		<cfargument name="nick" displayName="nick" type="string" hint="Nickname to identify user" required="true" />
		<cfargument name="peep" displayName="peep" type="string" hint="Peep name" required="true" />
		<cfargument name="msg" displayName="msg" type="string" hint="Message to send" required="true" />

		<cfstoredproc procedure="sendDirectMessage" datasource="demo">
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.nick#" />
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.peep#" />
			<cfprocparam cfsqltype="CF_SQL_VARCHAR" value="#arguments.msg#" />
		</cfstoredproc>

	</cffunction>

	<cfscript>
	/**
	* Converts a query object into an array of structures.
	*
	* @param query      The query to be transformed
	* @return This function returns a structure.
	* @author Nathan Dintenfass (nathan@changemedia.com)
	* @version 1, September 27, 2001
	*/
	function QueryToArrayOfStructures(theQuery){
	    var theArray = arraynew(1);
	    var cols = ListtoArray(theQuery.columnlist);
	    var row = 1;
	    var thisRow = "";
	    var col = 1;
	    for(row = 1; row LTE theQuery.recordcount; row = row + 1){
	        thisRow = structnew();
	        for(col = 1; col LTE arraylen(cols); col = col + 1){
	            thisRow[cols[col]] = theQuery[cols[col]][row];
	        }
	        arrayAppend(theArray,duplicate(thisRow));
	    }
	    return(theArray);
	}
	</cfscript>

</cfcomponent>